==> zbxe.beta.0.2.4.tgz: zbxe/modules/module/lang/jp.lang.php <==
<?php
    /**
     * @file   jp.lang.php
     * @author zero (zero@nzeo.com) 翻訳：RisaPapa
     * @brief  日本語言語パッケージ
     **/

    $lang->module_list = "モジュールリスト";
    $lang->module_index = "モジュールインデックス";
    $lang->module_category = "モジュールカテゴリ";
    $lang->module_info = "モジュール情報";
    $lang->add_shortcut = "管理者メニューに追加する";
    $lang->module_action = "動作";
    $lang->module_maker = "モジュール作者";
    $lang->module_history = "変更内容 ";
    $lang->category_title = "カテゴリ名";
    $lang->header_text = 'ヘッダー内容';
    $lang->footer_text = 'フッター内容';
    $lang->use_category = 'カテゴリ使用';
    $lang->category_title = 'カテゴリ名';
    $lang->checked_count = '選択された書き込み数';
    $lang->skin_default_info = 'スキン基本情報';
    $lang->skin_maker = 'スキン作者';
    $lang->skin_maker_homepage = '作者ホームページ';
    $lang->module_copy = "Copy module";

    $lang->cmd_add_shortcut = "ショットカット追加";
    $lang->cmd_install = "インストール";
    $lang->cmd_update = "アップデート";
    $lang->cmd_manage_category = 'カテゴリ管理';
    $lang->cmd_manage_grant = '権限管理';
    $lang->cmd_manage_skin = 'スキン管理';
    $lang->cmd_manage_document = '書き込み管理';

    $lang->msg_new_module = "モジュール作成";
    $lang->msg_update_module = "モジュール修正";
    $lang->msg_module_name_exists = "既に存在するモジュール名です。他の名前を入力してください。";
    $lang->msg_category_is_null = '登録されているカテゴリがありません。';
    $lang->msg_grant_is_null = '登録された権限がありません。';
    $lang->msg_no_checked_document = '選択された書き込みがありません。';
    $lang->msg_move_failed = '移動することができませんでした。';
    $lang->msg_cannot_delete_for_child = '下位カテゴリのカテゴリは削除することができません。';

    $lang->about_browser_title = "ブラウザのタイトルバーに表示される内容です。RSS/Trackbackでも使用します。";
    $lang->about_mid = "モジュール名は、http://アドレス/?mid=モジュール名、のように直接呼び出せる値です（英数＋_のみ可）。";
    $lang->about_default = "チェックすると、サイトに「 mid値」なしで接続した場合、デフォルトで表示します。";
    $lang->about_module_category = "カテゴリで管理できるようにします。モジュールのカテゴリの管理は、<a href=\"./?module=admin&amp;act=dispModuleAdminCategory\">モジュール管理 > モジュールカテゴリ </a>で行うことができます。";
    $lang->about_description= '管理用に用いられる説明です。';
    $lang->about_default = 'チェックすると、サイトに「mid値」なしで接続した場合、デフォルトで表示します。';
    $lang->about_header_text = 'モジュールのヘッダーに表示される内容です（HTMLタグが使用できる）。';
    $lang->about_footer_text = 'モジュールのフッターに表示される内容です。（HTMLタグが使用できる）。';
    $lang->about_skin = 'モジュールのスキンを選択することができます。';
    $lang->about_use_category = 'チェックするとカテゴリ機能が使用できます。';
    $lang->about_list_count = '１ページ当たりに表示される書き込みの数が指定できます（デフォルト１個）。';
    $lang->about_page_count = 'リストの下段に移動できるページのリンク数が指定できます（デフォルト１０個）。';
    $lang->about_admin_id = '該当するモジュールに対して最高権限を持つ管理者を指定することができます。「,（コンマ）」で区切って多数のＩＤが指定できます（管理者ページへのアクセスはできません）。';
    $lang->about_grant = '特定権限の対象をすべて解除するとログインしていない会員ユーザまで権限が与えられます。';
    $lang->about_module = "ゼロボードXEは、基本ライブラリの他は、すべてモジュールで構成されています。モジュール管理用のモジュールはインストールされたすべてを表示し、管理できるようにします。頻繁に使うモジュールは、【ショットカット追加】で行うと管理しやすなります。";

    $lang->about_extra_vars_default_value = '多重・単一選択などのデフォルト値が、複数必要な場合は、「, （コンマ）」でリンクを張ることができます。';
?>

==> zbxe.beta.0.2.6.tgz: zbxe/modules/module/lang/jp.lang.php <==
<?php
    /**
     * @file   jp.lang.php
     * @author zero (zero@nzeo.com) 翻訳：RisaPapa
     * @brief  日本語言語パッケージ
     **/

    $lang->module_list = "モジュールリスト";
    $lang->module_index = "モジュールインデックス";
    $lang->module_category = "モジュールカテゴリ";
    $lang->module_info = "モジュール情報";
    $lang->add_shortcut = "管理者メニューに追加する";
    $lang->module_action = "動作";
    $lang->module_maker = "モジュール作者";
    $lang->module_history = "変更内容 ";
    $lang->category_title = "カテゴリ名";
    $lang->header_text = 'ヘッダー内容';
    $lang->footer_text = 'フッター内容';
    $lang->use_category = 'カテゴリ使用';
    $lang->category_title = 'カテゴリ名';
    $lang->checked_count = '選択された書き込み数';
    $lang->skin_default_info = 'スキン基本情報';
    $lang->skin_maker = 'スキン作者';
    $lang->skin_maker_homepage = '作者ホームページ';
    $lang->module_copy = "モジュールコピー";

    $lang->cmd_add_shortcut = "ショットカット追加";
    $lang->cmd_install = "インストール";
    $lang->cmd_update = "アップデート";
    $lang->cmd_manage_category = 'カテゴリ管理';
    $lang->cmd_manage_grant = '権限管理';
    $lang->cmd_manage_skin = 'スキン管理';
    $lang->cmd_manage_document = '書き込み管理';

    $lang->msg_new_module = "モジュール作成";
    $lang->msg_update_module = "モジュール修正";
    $lang->msg_module_name_exists = "既に存在するモジュール名です。他の名前を入力してください。";
    $lang->msg_category_is_null = '登録されているカテゴリがありません。';
    $lang->msg_grant_is_null = '登録された権限がありません。';
    $lang->msg_no_checked_document = '選択された書き込みがありません。';
    $lang->msg_move_failed = '移動することができませんでした。';
    $lang->msg_cannot_delete_for_child = '下位カテゴリのカテゴリは削除することができません。';

    $lang->about_browser_title = "ブラウザのタイトルバーに表示される内容です。RSS/Trackbackでも使用します。";
    $lang->about_mid = "モジュール名は、http://アドレス/?mid=モジュール名、のように直接呼び出せる値です（英数＋[英数,_のみ可]）。";
    $lang->about_default = "チェックすると、サイトに「 mid値」なしで接続した場合、デフォルトで表示します。";
    $lang->about_module_category = "カテゴリで管理できるようにします。モジュールのカテゴリの管理は、<a href=\"./?module=admin&amp;act=dispModuleAdminCategory\">モジュール管理 > モジュールカテゴリ </a>で行うことができます。";
    $lang->about_description= '管理用に用いられる説明です。';
    $lang->about_default = 'チェックすると、サイトに「mid値」なしで接続した場合、デフォルトで表示します。';
    $lang->about_header_text = 'モジュールのヘッダーに表示される内容です（HTMLタグが使用できる）。';
    $lang->about_footer_text = 'モジュールのフッターに表示される内容です。（HTMLタグが使用できる）。';
    $lang->about_skin = 'モジュールのスキンを選択することができます。';
    $lang->about_use_category = 'チェックするとカテゴリ機能が使用できます。';
    $lang->about_list_count = '１ページ当たりに表示される書き込みの数が指定できます（デフォルト１個）。';
    $lang->about_page_count = 'リストの下段に移動できるページのリンク数が指定できます（デフォルト１０個）。';
    $lang->about_admin_id = '該当するモジュールに対して最高権限を持つ管理者を指定することができます。「,（コンマ）」で区切って多数のＩＤが指定できます（管理者ページへのアクセスはできません）。';
    $lang->about_grant = '特定権限の対象をすべて解除するとログインしていない会員ユーザまで権限が与えられます。';
    $lang->about_module = "ゼロボードXEは、基本ライブラリの他は、すべてモジュールで構成されています。モジュール管理用のモジュールはインストールされたすべてを表示し、管理できるようにします。頻繁に使うモジュールは、【ショットカット追加】で行うと管理しやすなります。";

    $lang->about_extra_vars_default_value = '多重・単一選択などのデフォルト値が、複数必要な場合は、「, （コンマ）」で区切って追加することができます。';
?>
